# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Algorithm-C3
Version:	0.11
Release:	10.%{__distinit}%{__distvers}
Summary:	Module for merging hierarchies using the C3 algorithm
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Algorithm-C3
Source0:	https://cpan.metacpan.org/modules/by-module/Algorithm/Algorithm-C3-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp) >= 0.01
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test
BuildRequires:	perl(Test::More) >= 0.47
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module implements the C3 algorithm.  Most of the uses I have for C3
revolve around class building and metamodels but it could also be used for
things like dependency resolution as well since it tends to do such a nice
job of preserving local precedence orderings.

%prep
%setup -q -n Algorithm-C3-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README t/
%{perl_vendorlib}/Algorithm/
%{_mandir}/man3/Algorithm::C3.3*

%changelog
* Fri Mar  3 2023 Paul Howarth <paul@city-fan.org> - 0.11-10
- Use SPDX-format license tag
- Use %%license unconditionally

* Wed Nov 11 2020 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - Set metadata for static dependency list and install
  - Move repository to GitHub
  - Minor test clean-ups
  - Fix Makefile.PL to work for authors in perl 5.26+
- Package new LICENSE file

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.10-14
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop legacy BuildRoot: and Group: tags

* Thu Aug  4 2016 Paul Howarth <paul@city-fan.org> - 0.10-6
- BR: perl-generators where available
- Simplify find command using -delete

* Sat Jun  6 2015 Paul Howarth <paul@city-fan.org> - 0.10-3
- Perl 5.22 rebuild

* Thu Sep  4 2014 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - Declare minimum version of perl as 5.6 in metadata
- Drop %%defattr, redundant since rpm 4.4

* Mon Mar  3 2014 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Convert to use ExtUtils::MakeMaker using distar
  - Include repo and bugtracker metadata
- This release by HAARG -> update source URL
- Switch to ExtUtils::MakeMaker flow

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 0.08-10
- BR: perl(Carp)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to run the test suite with LC_ALL=C

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 0.08-7
- Rebuild for perl 5.14.1 in Rawhide
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.08-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.08-5
- Fix dist tag for RHEL-6 Beta

* Wed Feb 17 2010 Paul Howarth <paul@city-fan.org> - 0.08-4
- dist tag for Rawhide no longer needs special-casing

* Tue Aug 11 2009 Paul Howarth <paul@city-fan.org> - 0.08-3
- Import from Fedora

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.08-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Jun 07 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.08-1
- Auto-update to 0.08 (by cpan-spec-update 0.01)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.07-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Mar 04 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.07-2
- Rebuild for new perl

* Thu May 31 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.07-1
- Update to 0.07
- Include t/ in doc
- Minor spec reworkage to deal with the once and future perl split

* Tue Nov 21 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.06-1
- Update to 0.06

* Wed Sep 06 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-2
- Bump

* Tue Sep 05 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.05-1
- Specfile autogenerated by cpanspec 1.69.1
